@@ -5,7 +5,6 @@ import configparser
 import os
 
 DEFAULT_SETTINGS = {
-    "EMAIL": "info@mutalyzer.nl",
     "NCBI_GFF3_URL": "https://eutils.ncbi.nlm.nih.gov/sviewer/viewer.cgi",
     "LRG_URL": "http://ftp.ebi.ac.uk/pub/databases/lrgex/",
     "MAX_FILE_SIZE": 10 * 1048576,
@@ -34,13 +33,32 @@ def setup_settings():
             sect: dict(loaded_settings.items(sect))
             for sect in loaded_settings.sections()
         }["config"]
-
+        for k in loaded_settings:
+            if loaded_settings[k] in {"yes", "true", "1"}:
+                loaded_settings[k] = True
+            elif loaded_settings[k] in {"no", "false", "0"}:
+                loaded_settings[k] = False
+            elif loaded_settings[k].isnumeric():
+                loaded_settings[k] = int(loaded_settings[k])
         settings.update(loaded_settings)
 
-    if settings.get("MAX_FILE_SIZE") and isinstance(settings["MAX_FILE_SIZE"], str):
-        settings["MAX_FILE_SIZE"] = eval(settings["MAX_FILE_SIZE"])
-
     return settings
 
 
 settings = setup_settings()
+
+
+def cache_dir():
+    return settings.get("MUTALYZER_CACHE_DIR")
+
+
+def cache_url():
+    return settings.get("MUTALYZER_API_URL")
+
+
+def lru_cache_maxsize():
+    return settings.get("MUTALYZER_LRU_CACHE_MAXSIZE")
+
+
+def cache_add():
+    return settings.get("MUTALYZER_FILE_CACHE_ADD")
